﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Research.Kinect.Nui;

namespace KinectWeatherMap
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ImageFrame lastDepthFrame;
        int[] colorOffsetMap;

        public MainWindow()
        {
            InitializeComponent();

            this.Loaded += (s, e) =>
            {
                InitKinect(Runtime.Kinects.FirstOrDefault());
            };
        }

        void InitKinect(Runtime runtime)
        {
            if (runtime == null)
                return;

            runtime.Initialize(RuntimeOptions.UseColor |
                               RuntimeOptions.UseDepthAndPlayerIndex |
                               RuntimeOptions.UseSkeletalTracking);

            runtime.DepthFrameReady += runtime_DepthFrameReady;
            runtime.VideoFrameReady += runtime_VideoFrameReady;
            runtime.SkeletonFrameReady += runtime_SkeletonFrameReady;

            runtime.VideoStream.Open(ImageStreamType.Video,
                                     2,
                                     ImageResolution.Resolution640x480,
                                     ImageType.Color);
            runtime.DepthStream.Open(ImageStreamType.Depth,
                                     2,
                                     ImageResolution.Resolution320x240,
                                     ImageType.DepthAndPlayerIndex);

            colorOffsetMap = new int[320 * 240 * 2];
            var view = new ImageViewArea();
            var cam = runtime.NuiCamera;
            for (int y = 0; y < 240; y++)
            {
                for (int x = 0; x < 320; x++)
                {
                    int colorX;
                    int colorY;
                    cam.GetColorPixelCoordinatesFromDepthPixel(ImageResolution.Resolution640x480,
                                                               view, x, y, 0,
                                                               out colorX, out colorY);
                    colorOffsetMap[2 * (x + y * 320)] = colorX;
                    colorOffsetMap[2 * (x + y * 320) + 1] = colorY;
                }
            }

        }

        void runtime_DepthFrameReady(object sender, ImageFrameReadyEventArgs e)
        {
            lastDepthFrame = e.ImageFrame;
        }

        void runtime_VideoFrameReady(object sender, ImageFrameReadyEventArgs e)
        {
            var image = e.ImageFrame.Image;

            var source = BitmapSource.Create(image.Width,
                                             image.Height,
                                             96, 96,
                                             PixelFormats.Bgr32, null,
                                             image.Bits,
                                             image.Width * image.BytesPerPixel);
            kinectImage.Source = source;
        }

        void runtime_SkeletonFrameReady(object sender, SkeletonFrameReadyEventArgs e)
        {

        }

    }
}
